#!/bin/bash
#
# Copyright (c) 2006 SUSE Linux Products GmbH Nuernberg, Germany.
#
# Author: Stephan Kulow   <coolo@suse.de>
#

#
# check if we are started as root
# only one of UID and USER must be set correctly
#
if test "$UID" != 0 -a "$USER" != root; then
    echo "You must be root to start $0."
    exit 1
fi

#
# check for sysconfig/displaymanager or rc.config
#
test -f /etc/sysconfig/displaymanager && source /etc/sysconfig/displaymanager
test -f /etc/sysconfig/security       && source /etc/sysconfig/security
test -f /etc/sysconfig/language       && source /etc/sysconfig/language

#
# source /etc/profile to get $kdedir
#
kdedir="/usr"
kdmdir="/var/adm/kdm"

# check for write permissions
[ -w ${kdmdir} ] || mkdir -p ${kdmdir}
[ -w ${kdmdir} ] || exit

#
# Set Style of Shutdown
#
ECHO_MODE="OneStar"
if test "$DISPLAYMANAGER_ROOT_LOGIN_LOCAL" = "yes"; then
    ALLOW_ROOT_LOGIN="true"
else
    ALLOW_ROOT_LOGIN="false"
fi

(
echo "[X-*-Greeter]"
if [ "$DISPLAYMANAGER_AD_INTEGRATION" = "yes" ]; then
  echo "PluginsLogin=winbind"
else
  if [ "$(/usr/sbin/pam-config -q --fp)" = "auth:" ]; then
    echo "PluginsLogin=generic"
  fi
fi
# kdm has en_US as default instead of simply reading LC_LANG :(
echo "Language="

echo "[Xdmcp]"
if [ "$DISPLAYMANAGER_REMOTE_ACCESS" = "yes" ]; then
  echo "Enable=true"
else
  echo "Enable=false"
fi

echo "[X-:0-Core]"
if [ "$DISPLAYMANAGER_AUTOLOGIN" ]; then
  echo "AutoLoginEnable=true"
  echo "AutoLoginUser=${DISPLAYMANAGER_AUTOLOGIN}"
else
  echo "AutoLoginEnable=false"
fi
if [ "$DISPLAYMANAGER_XSERVER_TCP_PORT_6000_OPEN" = "yes" ]; then
  echo "ServerArgsLocal=${DISPLAYMANAGER_KDM_LOCALARGS}"
else
  echo "ServerArgsLocal=-nolisten tcp ${DISPLAYMANAGER_KDM_LOCALARGS}"
fi
if [ "$DISPLAYMANAGER_PASSWORD_LESS_LOGIN" = "yes" ]; then
   echo "NoPassEnable=true"
   echo "NoPassAllUsers=true"
else
   echo "NoPassEnable=false"
   echo "NoPassAllUsers=false"
fi

echo "[X-:*-Core]"
echo "AllowRootLogin=${ALLOW_ROOT_LOGIN}"

echo "[X-*-Core]"

if test "$DISPLAYMANAGER_ROOT_LOGIN_REMOTE" = "yes"; then
    echo "AllowRootLogin=true"
else
    echo "AllowRootLogin=false"
fi

case "x$DISPLAYMANAGER_XSERVER" in
   xXgl)
	xgl=`type -p Xgl`
	echo "ServerCmd=$xgl $DISPLAYMANAGER_XGL_OPTS -br"
        echo "ServerTimeout=50"
        ;;
   xXorg)
        xorg=`type -p Xorg`
	echo "ServerCmd=$xorg -br"
	;;
   x)
        # empty value - younger than 11.0
        echo "ServerCmd=/usr/bin/X -br"
        ;;
   *)
	echo "#Unknown X server - leaving X"
	;;
esac

echo "[General]"
if [ "$DISPLAYMANAGER_STARTS_XSERVER" != "yes" ]; then
  echo "StaticServers="
fi

) > ${kdmdir}/kdmrc.sysconfig
